#!/usr/bin/env python

##############################################################################
#
# MODULE:       r.randomwalk.mult.py
#
# AUTHOR:       Martin Mergili
# CONTRIBUTORS: Massimiliano Alvioli, Ivan Marchesini
#
# PURPOSE:      Conceptual tool for mass movement propagation
#               Script for multi-core processing
#
# COPYRIGHT:    (c) 2013 - 2015 by the author
#               (c) 2013 - 2015 by the BOKU University, Vienna
#               (c) 2015        by the University of Vienna
#               (c) 2000 - 2015 by the GRASS Development Team
#
# VERSION:      20150730 (30 July 2015)
#
#               This program is free software under the GNU General Public
#               License (>=v2). Read the file COPYING that comes with GRASS
#               for details.
#
##############################################################################

#%module
#% description: Procedure for routing mass movements
#% keywords: Mass movement
#% keywords: Random walk
#% keywords: Raster
#% keywords: Routing
#%end

#%option
#% key: none
#% type: string
#% description: no option
#% required: no
#% multiple: no
#%end

import grass.script as grass #importing libraries
import os
import string
import sys

def main():

    none=options['none']
    cellsize=os.environ['cellsize'] #importing pixel size
    jid=os.environ['jid'] #importing number of model run
    os.environ['XINT']=jid #exporting number of model run
    rtemp=os.environ['rtemp'] #importing path to temporary directory
    pf=os.environ['pf'] #importing path to temporary directory
    nflag2=os.environ['nflag2'] #importing control for randomized validation area
    bflag2=os.environ['bflag2'] #importing control for reconstruction of observed impact area
    releasemap2=os.environ['releasemap2'] #importing control for release map

    grass.run_command('g.region', res=cellsize) #setting pixel size

    print
    print 'Routing flow and exporting result.'
    print

    grass.run_command('r.in.gdal', input=rtemp+'/_aoi.tif',
        output='_aoi', overwrite=True, quiet=True) #importing raster map of area of interest

    grass.run_command('r.in.gdal', input=rtemp+'/_elevation.tif',
        output='_elevation', overwrite=True, quiet=True) #importing elevation raster map

    if releasemap2=='1': grass.run_command('r.in.gdal', input=rtemp+'/_releasemap'+str(jid)+'.tif',
        output='_releasemap'+str(jid), overwrite=True, quiet=True) #importing release area raster map

    if bflag2=='1': grass.run_command('r.in.gdal', input=rtemp+'/_impactmap.tif',
        output='_impactmap', overwrite=True, quiet=True) #importing observed impact area raster map

    grass.run_command('r.randomwalk.main', flags='%s' % jid) #executing r.randomwalk.main

    if nflag2=='0': grass.run_command('r.out.gdal', input=pf+'_iis'+str(jid), output=rtemp+'/'+pf+'_iis'+str(jid),
        format='GTiff', flags='c', quiet=True, overwrite=True) #exporting impact indicator score map to tiff

    elif nflag2=='1': grass.run_command('r.out.gdal', input=pf+'_pi'+str(jid), output=rtemp+'/'+pf+'_pi'+str(jid),
        format='GTiff', flags='c', quiet=True, overwrite=True) #exporting impact probability map to tiff

    print
    print 'Completed.'
    print
    
if __name__ == '__main__':
    options, flags = grass.parser()
    main()
